@@ -12,4 +12,4 @@ from . import core
 
 @napari_hook_implementation
 def napari_get_reader(path: core.PathLike) -> Optional[core.ReaderFunction]:
-    return core.get_reader(path, compute=True)
+    return core.get_reader(path, in_memory=True)
